use bevy::prelude::*;
use std::time::Duration; // Needed for Timer in Player

// --- Components ---
#[derive(Component)]
pub struct Player {
    pub speed: f32,
    pub shoot_cooldown: Timer,
}

#[derive(Component)]
pub struct Bullet;

#[derive(Component, Clone, Copy, PartialEq, Eq, Debug)] // Added derive for common traits
pub enum EnemyType {
    Grunt,
    Boss, // Added Boss type
}

#[derive(Component)]
pub struct Enemy {
    pub enemy_type: EnemyType, // Add type field
    pub shoot_cooldown: Timer,
}

#[derive(Component)]
pub struct Invincible {
    pub timer: Timer,
}

#[derive(Component)]
pub struct FormationTarget {
    pub position: Vec3,
}

// Enum defining different ways an enemy can attack
#[derive(Component, Clone, Copy, PartialEq, Debug)]
pub enum AttackPattern {
    SwoopDive,      // Original pattern: dive towards center, then off screen
    DirectDive,     // Dive straight down
    Kamikaze(Vec3), // Dive towards a specific target location (e.g., player's last known position) - Needs target Vec3
    // Add more patterns later (e.g., FigureEight, Looping)
}

#[derive(Component, Clone, PartialEq, Debug)] // Added Debug derive
pub enum EnemyState {
    Entering,                // Flying onto the screen towards formation target
    InFormation,             // Holding position in the formation
    Attacking(AttackPattern), // Diving towards the player using a specific pattern
}

#[derive(Component)]
pub struct EnemyBullet;

// Game Over UI Component (might move to ui.rs later if more UI exists)
#[derive(Component)]
pub struct GameOverUI;